@@ -107,7 +107,8 @@ mb_col_set (MBColor *col, char *spec)
 	    }
 	  else
 	    {
-	      fprintf(stderr, "mbcolor: failed to parse color %s\n", spec);
+	      if (mb_want_warnings())
+		fprintf(stderr, "mbcolor: failed to parse color %s\n", spec);
 	      return False;
 	    } 
 
@@ -122,7 +123,8 @@ mb_col_set (MBColor *col, char *spec)
 			   DefaultColormap(pb->dpy, pb->scr),
 			   spec, &col->xcol))
 	    {
-	      fprintf(stderr, "mbcolor: failed to parse color %s\n", spec);
+	      if (mb_want_warnings())
+		fprintf(stderr, "mbcolor: failed to parse color %s\n", spec);
 	      return False;
 	    } 
 
@@ -374,11 +376,13 @@ _mb_font_load(MBFont *font)
     { 
       result = 1;  /* XXX: should retry with weight, slant set to '*' */ 
 
-      fprintf(stderr, "mbfont: failed to load %s, falling back to fixed\n", font_spec);
+      if (mb_want_warnings())
+	fprintf(stderr, "mbfont: failed to load %s, falling back to fixed\n", font_spec);
 
       if ((font->font = XLoadQueryFont(font->dpy, "fixed")) == NULL)
 	{
-	  fprintf(stderr, "mbfont: fixed failed, no usable fonts\n");
+	  if (mb_want_warnings())
+	    fprintf(stderr, "mbfont: fixed failed, no usable fonts\n");
 	  result = 0;
 	}
     }
@@ -406,6 +410,10 @@ mb_font_new(Display *dpy,
 #endif
   
   font = malloc(sizeof(MBFont));
+
+  if (font == NULL)
+    return NULL;
+
   memset(font, 0, sizeof(MBFont));
 
   if (family != NULL)
@@ -425,9 +433,12 @@ mb_font_new(Display *dpy,
    font->pgo_fontmap = pango_xft_get_font_map (font->dpy, DefaultScreen(dpy));
    font->fontdes     = pango_font_description_new ();
 
-   /* -- Needed ?
-   pango_context_set_language (w->pgo, pango_language_from_string ("ar_AE"));
-   */
+   /* If Pango is mis-setup the above will fail */
+   if (font->pgo_context == NULL || font->pgo_fontmap == NULL || font->fontdes == NULL)
+     {
+       free(font);
+       return NULL;
+     }
 
 #elif defined (USE_XFT)
 
@@ -581,8 +592,11 @@ MBFont*
 mb_font_new_from_string(Display *dpy, char *spec) 
 {
   MBFont *font = mb_font_new(dpy, NULL);
-  mb_font_set_from_string(font, spec); 
-  return font;
+
+  if (font)
+    return mb_font_set_from_string(font, spec); 
+
+  return NULL;
 }
 
 MBFont*
@@ -894,7 +908,7 @@ _clip_some_text (MBFont         *font,
 		 int             encoding,
 		 int             opts)
 {
-  int len = strlen(txt);
+  int len = strlen((char*)txt);
 
   /* we cant clip single char string */
   if (len < 2) return 0;
@@ -906,8 +920,7 @@ _clip_some_text (MBFont         *font,
       unsigned char *str = malloc(len+5);
       memset(str, 0, len+5);
 
-      /* len += 2; */
-      strcpy(str, txt);
+      strcpy((char*)str, (char*)txt);
 
       do {
 	  /* go back a glyth */
@@ -1058,20 +1071,21 @@ mb_font_render_simple (MBFont          *font,
 
   if (font->col == NULL) 
     {
-      fprintf(stderr, 
-	      "libmb: **error** font has no color set. unable to render\n");
+      if (mb_want_warnings())
+	fprintf(stderr, 
+		"libmb: **error** font has no color set. unable to render\n");
       return 0;
     }
 
   if (!_mb_font_is_font_object_fresh (font))
     _mb_font_load(font);
 
-  orig_len = len = strlen(text);
+  orig_len = len = strlen((char*)text);
 
   str = malloc(len+3);
   memset(str, 0, len+3);
 
-  strcpy(str, text);
+  strcpy((char*)str, (char*)text);
 
   render_w = mb_font_get_txt_width(font, str, len, encoding);
 
@@ -1085,13 +1099,18 @@ mb_font_render_simple (MBFont          *font,
        */
 
 
-
       len = _clip_some_text (font, width, str, encoding, opts);
 
       if (!len) { free(str); return 0; }
       
       if ((opts & MB_FONT_RENDER_OPTS_CLIP_TRAIL) && len > 3)
+	{
+	  /* Avoid having a space before the elipsis */
+	  while (len-1 >= 0 && str[len-1] == ' ')
+	    len--;
+
 	  want_dots = True;
+	}
     }
   else
     {
@@ -1147,12 +1166,12 @@ mb_font_render_simple_get_width (MBFont          *font,
   if (!_mb_font_is_font_object_fresh (font))
     _mb_font_load(font);
 
-  orig_len = len = strlen(text);
+  orig_len = len = strlen((char*)text);
 
   str = malloc(len+3);
   memset(str, 0, len+3);
 
-  strcpy(str, text);
+  strcpy((char*)str, (char*)text);
 
   render_w = mb_font_get_txt_width(font, str, len, encoding);
 
@@ -1257,7 +1276,7 @@ mb_layout_set_text(MBLayout       *layout,
 {
   if (layout->txt) free(layout->txt);
 
-  layout->txt = strdup(text);
+  layout->txt = (unsigned char*)strdup((char*)text);
   layout->txt_encoding = encoding;
 }
 
@@ -1304,7 +1323,7 @@ _mb_layout_render_magic (MBLayout        *layout,
 			 MBFontRenderOpts opts,
 			 Bool             do_render)
 {
-  unsigned char *orig_p, *p = strdup(layout->txt);
+  unsigned char *orig_p, *p = (unsigned char*)strdup((char*)layout->txt);
   unsigned char *q = p;
   unsigned char *backtrack = NULL;
   int            v_offset  = 0;
@@ -1326,7 +1345,7 @@ _mb_layout_render_magic (MBLayout        *layout,
 	  
 	  /* XXX q should be current_line_start */
 
-	  cur_width = mb_font_get_txt_width(layout->font, q, strlen(q), 
+	  cur_width = mb_font_get_txt_width(layout->font, q, strlen((char*)q), 
 					    layout->txt_encoding) ;
 	  
 	  if (cur_width > layout->width )
@@ -1405,7 +1424,7 @@ mb_layout_render (MBLayout        *layout,
 
   if (layout->_have_autocalc_size) /* Easy case */
     {
-      unsigned char *str = strdup(layout->txt), *start = NULL, *orig = NULL;
+      char *str = strdup((char*)layout->txt), *start = NULL, *orig = NULL;
 
       orig = str;
 
@@ -1426,7 +1445,7 @@ mb_layout_render (MBLayout        *layout,
 		                 x,
 		                 y,
 				 layout->width,
-				 start,
+				 (unsigned char*)start,
 		                 layout->txt_encoding,
 		                 0 );
 	  
